from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Activation
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.UI
import win32more.Windows.Win32.System.WinRT
class _GameBar_Meta_(ComPtr.__class__):
    pass
class GameBar(ComPtr, metaclass=_GameBar_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.GameBar'
    @winrt_classmethod
    def add_VisibilityChanged(cls: win32more.Windows.Gaming.UI.IGameBarStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_VisibilityChanged(cls: win32more.Windows.Gaming.UI.IGameBarStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_IsInputRedirectedChanged(cls: win32more.Windows.Gaming.UI.IGameBarStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_IsInputRedirectedChanged(cls: win32more.Windows.Gaming.UI.IGameBarStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Visible(cls: win32more.Windows.Gaming.UI.IGameBarStatics) -> Boolean: ...
    @winrt_classmethod
    def get_IsInputRedirected(cls: win32more.Windows.Gaming.UI.IGameBarStatics) -> Boolean: ...
    _GameBar_Meta_.IsInputRedirected = property(get_IsInputRedirected, None)
    _GameBar_Meta_.Visible = property(get_Visible, None)
class GameChatMessageOrigin(Enum, Int32):
    Voice = 0
    Text = 1
class GameChatMessageReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs
    _classid_ = 'Windows.Gaming.UI.GameChatMessageReceivedEventArgs'
    @winrt_mixinmethod
    def get_AppId(self: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppDisplayName(self: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SenderName(self: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Origin(self: win32more.Windows.Gaming.UI.IGameChatMessageReceivedEventArgs) -> win32more.Windows.Gaming.UI.GameChatMessageOrigin: ...
    AppDisplayName = property(get_AppDisplayName, None)
    AppId = property(get_AppId, None)
    Message = property(get_Message, None)
    Origin = property(get_Origin, None)
    SenderName = property(get_SenderName, None)
class GameChatOverlay(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.UI.IGameChatOverlay
    _classid_ = 'Windows.Gaming.UI.GameChatOverlay'
    @winrt_mixinmethod
    def get_DesiredPosition(self: win32more.Windows.Gaming.UI.IGameChatOverlay) -> win32more.Windows.Gaming.UI.GameChatOverlayPosition: ...
    @winrt_mixinmethod
    def put_DesiredPosition(self: win32more.Windows.Gaming.UI.IGameChatOverlay, value: win32more.Windows.Gaming.UI.GameChatOverlayPosition) -> Void: ...
    @winrt_mixinmethod
    def AddMessage(self: win32more.Windows.Gaming.UI.IGameChatOverlay, sender: WinRT_String, message: WinRT_String, origin: win32more.Windows.Gaming.UI.GameChatMessageOrigin) -> Void: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.Gaming.UI.IGameChatOverlayStatics) -> win32more.Windows.Gaming.UI.GameChatOverlay: ...
    DesiredPosition = property(get_DesiredPosition, put_DesiredPosition)
GameChatOverlayContract: UInt32 = 65536
class GameChatOverlayMessageSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.UI.IGameChatOverlayMessageSource
    _classid_ = 'Windows.Gaming.UI.GameChatOverlayMessageSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Gaming.UI.GameChatOverlayMessageSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Gaming.UI.GameChatOverlayMessageSource: ...
    @winrt_mixinmethod
    def add_MessageReceived(self: win32more.Windows.Gaming.UI.IGameChatOverlayMessageSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.UI.GameChatOverlayMessageSource, win32more.Windows.Gaming.UI.GameChatMessageReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MessageReceived(self: win32more.Windows.Gaming.UI.IGameChatOverlayMessageSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDelayBeforeClosingAfterMessageReceived(self: win32more.Windows.Gaming.UI.IGameChatOverlayMessageSource, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    MessageReceived = event()
class GameChatOverlayPosition(Enum, Int32):
    BottomCenter = 0
    BottomLeft = 1
    BottomRight = 2
    MiddleRight = 3
    MiddleLeft = 4
    TopCenter = 5
    TopLeft = 6
    TopRight = 7
class GameUIProviderActivatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.UI.IGameUIProviderActivatedEventArgs
    _classid_ = 'Windows.Gaming.UI.GameUIProviderActivatedEventArgs'
    @winrt_mixinmethod
    def get_GameUIArgs(self: win32more.Windows.Gaming.UI.IGameUIProviderActivatedEventArgs) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_mixinmethod
    def ReportCompleted(self: win32more.Windows.Gaming.UI.IGameUIProviderActivatedEventArgs, results: win32more.Windows.Foundation.Collections.ValueSet) -> Void: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.ApplicationModel.Activation.IActivatedEventArgs) -> win32more.Windows.ApplicationModel.Activation.ActivationKind: ...
    @winrt_mixinmethod
    def get_PreviousExecutionState(self: win32more.Windows.ApplicationModel.Activation.IActivatedEventArgs) -> win32more.Windows.ApplicationModel.Activation.ApplicationExecutionState: ...
    @winrt_mixinmethod
    def get_SplashScreen(self: win32more.Windows.ApplicationModel.Activation.IActivatedEventArgs) -> win32more.Windows.ApplicationModel.Activation.SplashScreen: ...
    GameUIArgs = property(get_GameUIArgs, None)
    Kind = property(get_Kind, None)
    PreviousExecutionState = property(get_PreviousExecutionState, None)
    SplashScreen = property(get_SplashScreen, None)
GamingUIProviderContract: UInt32 = 65536
class IGameBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameBarStatics'
    _iid_ = Guid('{1db9a292-cc78-4173-be45-b61e67283ea7}')
    @winrt_commethod(6)
    def add_VisibilityChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_VisibilityChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_IsInputRedirectedChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_IsInputRedirectedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_Visible(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_IsInputRedirected(self) -> Boolean: ...
    IsInputRedirected = property(get_IsInputRedirected, None)
    Visible = property(get_Visible, None)
    VisibilityChanged = event()
    IsInputRedirectedChanged = event()
class IGameChatMessageReceivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameChatMessageReceivedEventArgs'
    _iid_ = Guid('{a28201f1-3fb9-4e42-a403-7afce2023b1e}')
    @winrt_commethod(6)
    def get_AppId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppDisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SenderName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Message(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Origin(self) -> win32more.Windows.Gaming.UI.GameChatMessageOrigin: ...
    AppDisplayName = property(get_AppDisplayName, None)
    AppId = property(get_AppId, None)
    Message = property(get_Message, None)
    Origin = property(get_Origin, None)
    SenderName = property(get_SenderName, None)
class IGameChatOverlay(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameChatOverlay'
    _iid_ = Guid('{fbc64865-f6fc-4a48-ae07-03ac6ed43704}')
    @winrt_commethod(6)
    def get_DesiredPosition(self) -> win32more.Windows.Gaming.UI.GameChatOverlayPosition: ...
    @winrt_commethod(7)
    def put_DesiredPosition(self, value: win32more.Windows.Gaming.UI.GameChatOverlayPosition) -> Void: ...
    @winrt_commethod(8)
    def AddMessage(self, sender: WinRT_String, message: WinRT_String, origin: win32more.Windows.Gaming.UI.GameChatMessageOrigin) -> Void: ...
    DesiredPosition = property(get_DesiredPosition, put_DesiredPosition)
class IGameChatOverlayMessageSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameChatOverlayMessageSource'
    _iid_ = Guid('{1e177397-59fb-4f4f-8e9a-80acf817743c}')
    @winrt_commethod(6)
    def add_MessageReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.UI.GameChatOverlayMessageSource, win32more.Windows.Gaming.UI.GameChatMessageReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_MessageReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def SetDelayBeforeClosingAfterMessageReceived(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    MessageReceived = event()
class IGameChatOverlayStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameChatOverlayStatics'
    _iid_ = Guid('{89acf614-7867-49f7-9687-25d9dbf444d1}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.Gaming.UI.GameChatOverlay: ...
class IGameUIProviderActivatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.UI.IGameUIProviderActivatedEventArgs'
    _iid_ = Guid('{a7b3203e-caf7-4ded-bbd2-47de43bb6dd5}')
    @winrt_commethod(6)
    def get_GameUIArgs(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    @winrt_commethod(7)
    def ReportCompleted(self, results: win32more.Windows.Foundation.Collections.ValueSet) -> Void: ...
    GameUIArgs = property(get_GameUIArgs, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Media.ClosedCaptioning
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class ClosedCaptionColor(Enum, Int32):
    Default = 0
    White = 1
    Black = 2
    Red = 3
    Green = 4
    Blue = 5
    Yellow = 6
    Magenta = 7
    Cyan = 8
class ClosedCaptionEdgeEffect(Enum, Int32):
    Default = 0
    None_ = 1
    Raised = 2
    Depressed = 3
    Uniform = 4
    DropShadow = 5
class ClosedCaptionOpacity(Enum, Int32):
    Default = 0
    OneHundredPercent = 1
    SeventyFivePercent = 2
    TwentyFivePercent = 3
    ZeroPercent = 4
class _ClosedCaptionProperties_Meta_(ComPtr.__class__):
    pass
class ClosedCaptionProperties(ComPtr, metaclass=_ClosedCaptionProperties_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ClosedCaptioning.ClosedCaptionProperties'
    @winrt_classmethod
    def add_PropertiesChanged(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_PropertiesChanged(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_FontColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_classmethod
    def get_ComputedFontColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_FontOpacity(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    @winrt_classmethod
    def get_FontSize(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionSize: ...
    @winrt_classmethod
    def get_FontStyle(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionStyle: ...
    @winrt_classmethod
    def get_FontEffect(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionEdgeEffect: ...
    @winrt_classmethod
    def get_BackgroundColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_classmethod
    def get_ComputedBackgroundColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BackgroundOpacity(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    @winrt_classmethod
    def get_RegionColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_classmethod
    def get_ComputedRegionColor(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_RegionOpacity(cls: win32more.Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    _ClosedCaptionProperties_Meta_.BackgroundColor = property(get_BackgroundColor, None)
    _ClosedCaptionProperties_Meta_.BackgroundOpacity = property(get_BackgroundOpacity, None)
    _ClosedCaptionProperties_Meta_.ComputedBackgroundColor = property(get_ComputedBackgroundColor, None)
    _ClosedCaptionProperties_Meta_.ComputedFontColor = property(get_ComputedFontColor, None)
    _ClosedCaptionProperties_Meta_.ComputedRegionColor = property(get_ComputedRegionColor, None)
    _ClosedCaptionProperties_Meta_.FontColor = property(get_FontColor, None)
    _ClosedCaptionProperties_Meta_.FontEffect = property(get_FontEffect, None)
    _ClosedCaptionProperties_Meta_.FontOpacity = property(get_FontOpacity, None)
    _ClosedCaptionProperties_Meta_.FontSize = property(get_FontSize, None)
    _ClosedCaptionProperties_Meta_.FontStyle = property(get_FontStyle, None)
    _ClosedCaptionProperties_Meta_.RegionColor = property(get_RegionColor, None)
    _ClosedCaptionProperties_Meta_.RegionOpacity = property(get_RegionOpacity, None)
class ClosedCaptionSize(Enum, Int32):
    Default = 0
    FiftyPercent = 1
    OneHundredPercent = 2
    OneHundredFiftyPercent = 3
    TwoHundredPercent = 4
class ClosedCaptionStyle(Enum, Int32):
    Default = 0
    MonospacedWithSerifs = 1
    ProportionalWithSerifs = 2
    MonospacedWithoutSerifs = 3
    ProportionalWithoutSerifs = 4
    Casual = 5
    Cursive = 6
    SmallCapitals = 7
class IClosedCaptionPropertiesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics'
    _iid_ = Guid('{10aa1f84-cc30-4141-b503-5272289e0c20}')
    @winrt_commethod(6)
    def get_FontColor(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_commethod(7)
    def get_ComputedFontColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(8)
    def get_FontOpacity(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    @winrt_commethod(9)
    def get_FontSize(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionSize: ...
    @winrt_commethod(10)
    def get_FontStyle(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionStyle: ...
    @winrt_commethod(11)
    def get_FontEffect(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionEdgeEffect: ...
    @winrt_commethod(12)
    def get_BackgroundColor(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_commethod(13)
    def get_ComputedBackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(14)
    def get_BackgroundOpacity(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    @winrt_commethod(15)
    def get_RegionColor(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionColor: ...
    @winrt_commethod(16)
    def get_ComputedRegionColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(17)
    def get_RegionOpacity(self) -> win32more.Windows.Media.ClosedCaptioning.ClosedCaptionOpacity: ...
    BackgroundColor = property(get_BackgroundColor, None)
    BackgroundOpacity = property(get_BackgroundOpacity, None)
    ComputedBackgroundColor = property(get_ComputedBackgroundColor, None)
    ComputedFontColor = property(get_ComputedFontColor, None)
    ComputedRegionColor = property(get_ComputedRegionColor, None)
    FontColor = property(get_FontColor, None)
    FontEffect = property(get_FontEffect, None)
    FontOpacity = property(get_FontOpacity, None)
    FontSize = property(get_FontSize, None)
    FontStyle = property(get_FontStyle, None)
    RegionColor = property(get_RegionColor, None)
    RegionOpacity = property(get_RegionOpacity, None)
class IClosedCaptionPropertiesStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.ClosedCaptioning.IClosedCaptionPropertiesStatics2'
    _iid_ = Guid('{9de26870-37de-4197-8845-9a48dc5ac317}')
    @winrt_commethod(6)
    def add_PropertiesChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PropertiesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PropertiesChanged = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Security.WinWlx
import win32more.Windows.Win32.System.StationsAndDesktops
import win32more.Windows.Win32.UI.WindowsAndMessaging
WLX_VERSION_1_0: UInt32 = 65536
WLX_VERSION_1_1: UInt32 = 65537
WLX_VERSION_1_2: UInt32 = 65538
WLX_VERSION_1_3: UInt32 = 65539
WLX_VERSION_1_4: UInt32 = 65540
WLX_CURRENT_VERSION: UInt32 = 65540
WLX_SAS_TYPE_TIMEOUT: UInt32 = 0
WLX_SAS_TYPE_CTRL_ALT_DEL: UInt32 = 1
WLX_SAS_TYPE_SCRNSVR_TIMEOUT: UInt32 = 2
WLX_SAS_TYPE_SCRNSVR_ACTIVITY: UInt32 = 3
WLX_SAS_TYPE_USER_LOGOFF: UInt32 = 4
WLX_SAS_TYPE_SC_INSERT: UInt32 = 5
WLX_SAS_TYPE_SC_REMOVE: UInt32 = 6
WLX_SAS_TYPE_AUTHENTICATED: UInt32 = 7
WLX_SAS_TYPE_SC_FIRST_READER_ARRIVED: UInt32 = 8
WLX_SAS_TYPE_SC_LAST_READER_REMOVED: UInt32 = 9
WLX_SAS_TYPE_SWITCHUSER: UInt32 = 10
WLX_SAS_TYPE_MAX_MSFT_VALUE: UInt32 = 127
WLX_LOGON_OPT_NO_PROFILE: UInt32 = 1
WLX_PROFILE_TYPE_V1_0: UInt32 = 1
WLX_PROFILE_TYPE_V2_0: UInt32 = 2
WLX_SAS_ACTION_LOGON: UInt32 = 1
WLX_SAS_ACTION_NONE: UInt32 = 2
WLX_SAS_ACTION_LOCK_WKSTA: UInt32 = 3
WLX_SAS_ACTION_LOGOFF: UInt32 = 4
WLX_SAS_ACTION_PWD_CHANGED: UInt32 = 6
WLX_SAS_ACTION_TASKLIST: UInt32 = 7
WLX_SAS_ACTION_UNLOCK_WKSTA: UInt32 = 8
WLX_SAS_ACTION_FORCE_LOGOFF: UInt32 = 9
WLX_SAS_ACTION_SHUTDOWN_SLEEP: UInt32 = 12
WLX_SAS_ACTION_SHUTDOWN_SLEEP2: UInt32 = 13
WLX_SAS_ACTION_SHUTDOWN_HIBERNATE: UInt32 = 14
WLX_SAS_ACTION_RECONNECTED: UInt32 = 15
WLX_SAS_ACTION_DELAYED_FORCE_LOGOFF: UInt32 = 16
WLX_SAS_ACTION_SWITCH_CONSOLE: UInt32 = 17
WLX_WM_SAS: UInt32 = 1625
WLX_DLG_SAS: UInt32 = 101
WLX_DLG_INPUT_TIMEOUT: UInt32 = 102
WLX_DLG_SCREEN_SAVER_TIMEOUT: UInt32 = 103
WLX_DLG_USER_LOGOFF: UInt32 = 104
WLX_DIRECTORY_LENGTH: UInt32 = 256
WLX_CREDENTIAL_TYPE_V1_0: UInt32 = 1
WLX_CREDENTIAL_TYPE_V2_0: UInt32 = 2
WLX_CONSOLESWITCHCREDENTIAL_TYPE_V1_0: UInt32 = 1
STATUSMSG_OPTION_NOANIMATION: UInt32 = 1
STATUSMSG_OPTION_SETFOREGROUND: UInt32 = 2
WLX_DESKTOP_NAME: UInt32 = 1
WLX_DESKTOP_HANDLE: UInt32 = 2
WLX_CREATE_INSTANCE_ONLY: UInt32 = 1
WLX_CREATE_USER: UInt32 = 2
WLX_OPTION_USE_CTRL_ALT_DEL: UInt32 = 1
WLX_OPTION_CONTEXT_POINTER: UInt32 = 2
WLX_OPTION_USE_SMART_CARD: UInt32 = 3
WLX_OPTION_FORCE_LOGOFF_TIME: UInt32 = 4
WLX_OPTION_IGNORE_AUTO_LOGON: UInt32 = 8
WLX_OPTION_NO_SWITCH_ON_SAS: UInt32 = 9
WLX_OPTION_SMART_CARD_PRESENT: UInt32 = 65537
WLX_OPTION_SMART_CARD_INFO: UInt32 = 65538
WLX_OPTION_DISPATCH_TABLE_SIZE: UInt32 = 65539
@winfunctype_pointer
def PFNMSGECALLBACK(bVerbose: win32more.Windows.Win32.Foundation.BOOL, lpMessage: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PWLX_ASSIGN_SHELL_PROTECTION(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hToken: win32more.Windows.Win32.Foundation.HANDLE, hProcess: win32more.Windows.Win32.Foundation.HANDLE, hThread: win32more.Windows.Win32.Foundation.HANDLE) -> Int32: ...
@winfunctype_pointer
def PWLX_CHANGE_PASSWORD_NOTIFY(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pMprInfo: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_MPR_NOTIFY_INFO), dwChangeInfo: UInt32) -> Int32: ...
@winfunctype_pointer
def PWLX_CHANGE_PASSWORD_NOTIFY_EX(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pMprInfo: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_MPR_NOTIFY_INFO), dwChangeInfo: UInt32, ProviderName: win32more.Windows.Win32.Foundation.PWSTR, Reserved: VoidPtr) -> Int32: ...
@winfunctype_pointer
def PWLX_CLOSE_USER_DESKTOP(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pDesktop: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_DESKTOP), hToken: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_CREATE_USER_DESKTOP(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hToken: win32more.Windows.Win32.Foundation.HANDLE, Flags: UInt32, pszDesktopName: win32more.Windows.Win32.Foundation.PWSTR, ppDesktop: POINTER(POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_DESKTOP))) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_DIALOG_BOX(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hInst: win32more.Windows.Win32.Foundation.HANDLE, lpszTemplate: win32more.Windows.Win32.Foundation.PWSTR, hwndOwner: win32more.Windows.Win32.Foundation.HWND, dlgprc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC) -> Int32: ...
@winfunctype_pointer
def PWLX_DIALOG_BOX_INDIRECT(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hInst: win32more.Windows.Win32.Foundation.HANDLE, hDialogTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hwndOwner: win32more.Windows.Win32.Foundation.HWND, dlgprc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC) -> Int32: ...
@winfunctype_pointer
def PWLX_DIALOG_BOX_INDIRECT_PARAM(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hInst: win32more.Windows.Win32.Foundation.HANDLE, hDialogTemplate: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.DLGTEMPLATE), hwndOwner: win32more.Windows.Win32.Foundation.HWND, dlgprc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PWLX_DIALOG_BOX_PARAM(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hInst: win32more.Windows.Win32.Foundation.HANDLE, lpszTemplate: win32more.Windows.Win32.Foundation.PWSTR, hwndOwner: win32more.Windows.Win32.Foundation.HWND, dlgprc: win32more.Windows.Win32.UI.WindowsAndMessaging.DLGPROC, dwInitParam: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def PWLX_DISCONNECT() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_GET_OPTION(hWlx: win32more.Windows.Win32.Foundation.HANDLE, Option: UInt32, Value: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_GET_SOURCE_DESKTOP(hWlx: win32more.Windows.Win32.Foundation.HANDLE, ppDesktop: POINTER(POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_DESKTOP))) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_MESSAGE_BOX(hWlx: win32more.Windows.Win32.Foundation.HANDLE, hwndOwner: win32more.Windows.Win32.Foundation.HWND, lpszText: win32more.Windows.Win32.Foundation.PWSTR, lpszTitle: win32more.Windows.Win32.Foundation.PWSTR, fuStyle: UInt32) -> Int32: ...
@winfunctype_pointer
def PWLX_QUERY_CLIENT_CREDENTIALS(pCred: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_CLIENT_CREDENTIALS_INFO_V1_0)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_QUERY_CONSOLESWITCH_CREDENTIALS(pCred: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0)) -> UInt32: ...
@winfunctype_pointer
def PWLX_QUERY_IC_CREDENTIALS(pCred: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_CLIENT_CREDENTIALS_INFO_V1_0)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_QUERY_TERMINAL_SERVICES_DATA(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pTSData: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_TERMINAL_SERVICES_DATA), UserName: win32more.Windows.Win32.Foundation.PWSTR, Domain: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
@winfunctype_pointer
def PWLX_QUERY_TS_LOGON_CREDENTIALS(pCred: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_CLIENT_CREDENTIALS_INFO_V2_0)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_SAS_NOTIFY(hWlx: win32more.Windows.Win32.Foundation.HANDLE, dwSasType: UInt32) -> Void: ...
@winfunctype_pointer
def PWLX_SET_CONTEXT_POINTER(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pWlxContext: VoidPtr) -> Void: ...
@winfunctype_pointer
def PWLX_SET_OPTION(hWlx: win32more.Windows.Win32.Foundation.HANDLE, Option: UInt32, Value: UIntPtr, OldValue: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_SET_RETURN_DESKTOP(hWlx: win32more.Windows.Win32.Foundation.HANDLE, pDesktop: POINTER(win32more.Windows.Win32.Security.WinWlx.WLX_DESKTOP)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_SET_TIMEOUT(hWlx: win32more.Windows.Win32.Foundation.HANDLE, Timeout: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PWLX_SWITCH_DESKTOP_TO_USER(hWlx: win32more.Windows.Win32.Foundation.HANDLE) -> Int32: ...
@winfunctype_pointer
def PWLX_SWITCH_DESKTOP_TO_WINLOGON(hWlx: win32more.Windows.Win32.Foundation.HANDLE) -> Int32: ...
@winfunctype_pointer
def PWLX_USE_CTRL_ALT_DEL(hWlx: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype_pointer
def PWLX_WIN31_MIGRATE(hWlx: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
class WLX_CLIENT_CREDENTIALS_INFO_V1_0(Structure):
    dwType: UInt32
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszDomain: win32more.Windows.Win32.Foundation.PWSTR
    pszPassword: win32more.Windows.Win32.Foundation.PWSTR
    fPromptForPassword: win32more.Windows.Win32.Foundation.BOOL
class WLX_CLIENT_CREDENTIALS_INFO_V2_0(Structure):
    dwType: UInt32
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszDomain: win32more.Windows.Win32.Foundation.PWSTR
    pszPassword: win32more.Windows.Win32.Foundation.PWSTR
    fPromptForPassword: win32more.Windows.Win32.Foundation.BOOL
    fDisconnectOnLogonFailure: win32more.Windows.Win32.Foundation.BOOL
class WLX_CONSOLESWITCH_CREDENTIALS_INFO_V1_0(Structure):
    dwType: UInt32
    UserToken: win32more.Windows.Win32.Foundation.HANDLE
    LogonId: win32more.Windows.Win32.Foundation.LUID
    Quotas: win32more.Windows.Win32.Security.QUOTA_LIMITS
    UserName: win32more.Windows.Win32.Foundation.PWSTR
    Domain: win32more.Windows.Win32.Foundation.PWSTR
    LogonTime: Int64
    SmartCardLogon: win32more.Windows.Win32.Foundation.BOOL
    ProfileLength: UInt32
    MessageType: UInt32
    LogonCount: UInt16
    BadPasswordCount: UInt16
    ProfileLogonTime: Int64
    LogoffTime: Int64
    KickOffTime: Int64
    PasswordLastSet: Int64
    PasswordCanChange: Int64
    PasswordMustChange: Int64
    LogonScript: win32more.Windows.Win32.Foundation.PWSTR
    HomeDirectory: win32more.Windows.Win32.Foundation.PWSTR
    FullName: win32more.Windows.Win32.Foundation.PWSTR
    ProfilePath: win32more.Windows.Win32.Foundation.PWSTR
    HomeDirectoryDrive: win32more.Windows.Win32.Foundation.PWSTR
    LogonServer: win32more.Windows.Win32.Foundation.PWSTR
    UserFlags: UInt32
    PrivateDataLen: UInt32
    PrivateData: POINTER(Byte)
class WLX_DESKTOP(Structure):
    Size: UInt32
    Flags: UInt32
    hDesktop: win32more.Windows.Win32.System.StationsAndDesktops.HDESK
    pszDesktopName: win32more.Windows.Win32.Foundation.PWSTR
class WLX_DISPATCH_VERSION_1_0(Structure):
    WlxUseCtrlAltDel: win32more.Windows.Win32.Security.WinWlx.PWLX_USE_CTRL_ALT_DEL
    WlxSetContextPointer: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_CONTEXT_POINTER
    WlxSasNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_SAS_NOTIFY
    WlxSetTimeout: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_TIMEOUT
    WlxAssignShellProtection: win32more.Windows.Win32.Security.WinWlx.PWLX_ASSIGN_SHELL_PROTECTION
    WlxMessageBox: win32more.Windows.Win32.Security.WinWlx.PWLX_MESSAGE_BOX
    WlxDialogBox: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX
    WlxDialogBoxParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_PARAM
    WlxDialogBoxIndirect: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT
    WlxDialogBoxIndirectParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT_PARAM
    WlxSwitchDesktopToUser: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_USER
    WlxSwitchDesktopToWinlogon: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_WINLOGON
    WlxChangePasswordNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY
class WLX_DISPATCH_VERSION_1_1(Structure):
    WlxUseCtrlAltDel: win32more.Windows.Win32.Security.WinWlx.PWLX_USE_CTRL_ALT_DEL
    WlxSetContextPointer: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_CONTEXT_POINTER
    WlxSasNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_SAS_NOTIFY
    WlxSetTimeout: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_TIMEOUT
    WlxAssignShellProtection: win32more.Windows.Win32.Security.WinWlx.PWLX_ASSIGN_SHELL_PROTECTION
    WlxMessageBox: win32more.Windows.Win32.Security.WinWlx.PWLX_MESSAGE_BOX
    WlxDialogBox: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX
    WlxDialogBoxParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_PARAM
    WlxDialogBoxIndirect: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT
    WlxDialogBoxIndirectParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT_PARAM
    WlxSwitchDesktopToUser: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_USER
    WlxSwitchDesktopToWinlogon: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_WINLOGON
    WlxChangePasswordNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY
    WlxGetSourceDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_SOURCE_DESKTOP
    WlxSetReturnDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_RETURN_DESKTOP
    WlxCreateUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CREATE_USER_DESKTOP
    WlxChangePasswordNotifyEx: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY_EX
class WLX_DISPATCH_VERSION_1_2(Structure):
    WlxUseCtrlAltDel: win32more.Windows.Win32.Security.WinWlx.PWLX_USE_CTRL_ALT_DEL
    WlxSetContextPointer: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_CONTEXT_POINTER
    WlxSasNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_SAS_NOTIFY
    WlxSetTimeout: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_TIMEOUT
    WlxAssignShellProtection: win32more.Windows.Win32.Security.WinWlx.PWLX_ASSIGN_SHELL_PROTECTION
    WlxMessageBox: win32more.Windows.Win32.Security.WinWlx.PWLX_MESSAGE_BOX
    WlxDialogBox: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX
    WlxDialogBoxParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_PARAM
    WlxDialogBoxIndirect: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT
    WlxDialogBoxIndirectParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT_PARAM
    WlxSwitchDesktopToUser: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_USER
    WlxSwitchDesktopToWinlogon: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_WINLOGON
    WlxChangePasswordNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY
    WlxGetSourceDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_SOURCE_DESKTOP
    WlxSetReturnDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_RETURN_DESKTOP
    WlxCreateUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CREATE_USER_DESKTOP
    WlxChangePasswordNotifyEx: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY_EX
    WlxCloseUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CLOSE_USER_DESKTOP
class WLX_DISPATCH_VERSION_1_3(Structure):
    WlxUseCtrlAltDel: win32more.Windows.Win32.Security.WinWlx.PWLX_USE_CTRL_ALT_DEL
    WlxSetContextPointer: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_CONTEXT_POINTER
    WlxSasNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_SAS_NOTIFY
    WlxSetTimeout: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_TIMEOUT
    WlxAssignShellProtection: win32more.Windows.Win32.Security.WinWlx.PWLX_ASSIGN_SHELL_PROTECTION
    WlxMessageBox: win32more.Windows.Win32.Security.WinWlx.PWLX_MESSAGE_BOX
    WlxDialogBox: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX
    WlxDialogBoxParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_PARAM
    WlxDialogBoxIndirect: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT
    WlxDialogBoxIndirectParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT_PARAM
    WlxSwitchDesktopToUser: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_USER
    WlxSwitchDesktopToWinlogon: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_WINLOGON
    WlxChangePasswordNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY
    WlxGetSourceDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_SOURCE_DESKTOP
    WlxSetReturnDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_RETURN_DESKTOP
    WlxCreateUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CREATE_USER_DESKTOP
    WlxChangePasswordNotifyEx: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY_EX
    WlxCloseUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CLOSE_USER_DESKTOP
    WlxSetOption: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_OPTION
    WlxGetOption: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_OPTION
    WlxWin31Migrate: win32more.Windows.Win32.Security.WinWlx.PWLX_WIN31_MIGRATE
    WlxQueryClientCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_CLIENT_CREDENTIALS
    WlxQueryInetConnectorCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_IC_CREDENTIALS
    WlxDisconnect: win32more.Windows.Win32.Security.WinWlx.PWLX_DISCONNECT
    WlxQueryTerminalServicesData: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_TERMINAL_SERVICES_DATA
class WLX_DISPATCH_VERSION_1_4(Structure):
    WlxUseCtrlAltDel: win32more.Windows.Win32.Security.WinWlx.PWLX_USE_CTRL_ALT_DEL
    WlxSetContextPointer: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_CONTEXT_POINTER
    WlxSasNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_SAS_NOTIFY
    WlxSetTimeout: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_TIMEOUT
    WlxAssignShellProtection: win32more.Windows.Win32.Security.WinWlx.PWLX_ASSIGN_SHELL_PROTECTION
    WlxMessageBox: win32more.Windows.Win32.Security.WinWlx.PWLX_MESSAGE_BOX
    WlxDialogBox: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX
    WlxDialogBoxParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_PARAM
    WlxDialogBoxIndirect: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT
    WlxDialogBoxIndirectParam: win32more.Windows.Win32.Security.WinWlx.PWLX_DIALOG_BOX_INDIRECT_PARAM
    WlxSwitchDesktopToUser: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_USER
    WlxSwitchDesktopToWinlogon: win32more.Windows.Win32.Security.WinWlx.PWLX_SWITCH_DESKTOP_TO_WINLOGON
    WlxChangePasswordNotify: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY
    WlxGetSourceDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_SOURCE_DESKTOP
    WlxSetReturnDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_RETURN_DESKTOP
    WlxCreateUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CREATE_USER_DESKTOP
    WlxChangePasswordNotifyEx: win32more.Windows.Win32.Security.WinWlx.PWLX_CHANGE_PASSWORD_NOTIFY_EX
    WlxCloseUserDesktop: win32more.Windows.Win32.Security.WinWlx.PWLX_CLOSE_USER_DESKTOP
    WlxSetOption: win32more.Windows.Win32.Security.WinWlx.PWLX_SET_OPTION
    WlxGetOption: win32more.Windows.Win32.Security.WinWlx.PWLX_GET_OPTION
    WlxWin31Migrate: win32more.Windows.Win32.Security.WinWlx.PWLX_WIN31_MIGRATE
    WlxQueryClientCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_CLIENT_CREDENTIALS
    WlxQueryInetConnectorCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_IC_CREDENTIALS
    WlxDisconnect: win32more.Windows.Win32.Security.WinWlx.PWLX_DISCONNECT
    WlxQueryTerminalServicesData: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_TERMINAL_SERVICES_DATA
    WlxQueryConsoleSwitchCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_CONSOLESWITCH_CREDENTIALS
    WlxQueryTsLogonCredentials: win32more.Windows.Win32.Security.WinWlx.PWLX_QUERY_TS_LOGON_CREDENTIALS
class WLX_MPR_NOTIFY_INFO(Structure):
    pszUserName: win32more.Windows.Win32.Foundation.PWSTR
    pszDomain: win32more.Windows.Win32.Foundation.PWSTR
    pszPassword: win32more.Windows.Win32.Foundation.PWSTR
    pszOldPassword: win32more.Windows.Win32.Foundation.PWSTR
class WLX_NOTIFICATION_INFO(Structure):
    Size: UInt32
    Flags: UInt32
    UserName: win32more.Windows.Win32.Foundation.PWSTR
    Domain: win32more.Windows.Win32.Foundation.PWSTR
    WindowStation: win32more.Windows.Win32.Foundation.PWSTR
    hToken: win32more.Windows.Win32.Foundation.HANDLE
    hDesktop: win32more.Windows.Win32.System.StationsAndDesktops.HDESK
    pStatusCallback: win32more.Windows.Win32.Security.WinWlx.PFNMSGECALLBACK
class WLX_PROFILE_V1_0(Structure):
    dwType: UInt32
    pszProfile: win32more.Windows.Win32.Foundation.PWSTR
class WLX_PROFILE_V2_0(Structure):
    dwType: UInt32
    pszProfile: win32more.Windows.Win32.Foundation.PWSTR
    pszPolicy: win32more.Windows.Win32.Foundation.PWSTR
    pszNetworkDefaultUserProfile: win32more.Windows.Win32.Foundation.PWSTR
    pszServerName: win32more.Windows.Win32.Foundation.PWSTR
    pszEnvironment: win32more.Windows.Win32.Foundation.PWSTR
class WLX_SC_NOTIFICATION_INFO(Structure):
    pszCard: win32more.Windows.Win32.Foundation.PWSTR
    pszReader: win32more.Windows.Win32.Foundation.PWSTR
    pszContainer: win32more.Windows.Win32.Foundation.PWSTR
    pszCryptoProvider: win32more.Windows.Win32.Foundation.PWSTR
WLX_SHUTDOWN_TYPE = UInt32
WLX_SAS_ACTION_SHUTDOWN: win32more.Windows.Win32.Security.WinWlx.WLX_SHUTDOWN_TYPE = 5
WLX_SAS_ACTION_SHUTDOWN_REBOOT: win32more.Windows.Win32.Security.WinWlx.WLX_SHUTDOWN_TYPE = 11
WLX_SAS_ACTION_SHUTDOWN_POWER_OFF: win32more.Windows.Win32.Security.WinWlx.WLX_SHUTDOWN_TYPE = 10
class WLX_TERMINAL_SERVICES_DATA(Structure):
    ProfilePath: Char * 257
    HomeDir: Char * 257
    HomeDirDrive: Char * 4


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.DeviceQuery
import win32more.Windows.Win32.Devices.Properties
import win32more.Windows.Win32.Foundation
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevCreateObjectQuery(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-1.dll')
def DevCreateObjectQueryEx(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), cExtendedParameterCount: UInt32, pExtendedParameters: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_PARAMETER), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevCreateObjectQueryFromId(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszObjectId: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-1.dll')
def DevCreateObjectQueryFromIdEx(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszObjectId: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), cExtendedParameterCount: UInt32, pExtendedParameters: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_PARAMETER), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevCreateObjectQueryFromIds(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszzObjectIds: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-1.dll')
def DevCreateObjectQueryFromIdsEx(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszzObjectIds: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), cExtendedParameterCount: UInt32, pExtendedParameters: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_PARAMETER), pCallback: win32more.Windows.Win32.Devices.DeviceQuery.PDEV_QUERY_RESULT_CALLBACK, pContext: VoidPtr, phDevQuery: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevCloseObjectQuery(hDevQuery: win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY) -> Void: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevGetObjects(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), pcObjectCount: POINTER(UInt32), ppObjects: POINTER(POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-1.dll')
def DevGetObjectsEx(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cFilterExpressionCount: UInt32, pFilter: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_FILTER_EXPRESSION), cExtendedParameterCount: UInt32, pExtendedParameters: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_PARAMETER), pcObjectCount: POINTER(UInt32), ppObjects: POINTER(POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevFreeObjects(cObjectCount: UInt32, pObjects: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT)) -> Void: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevGetObjectProperties(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszObjectId: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), pcPropertyCount: POINTER(UInt32), ppProperties: POINTER(POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-1.dll')
def DevGetObjectPropertiesEx(ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE, pszObjectId: win32more.Windows.Win32.Foundation.PWSTR, QueryFlags: UInt32, cRequestedProperties: UInt32, pRequestedProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPCOMPKEY), cExtendedParameterCount: UInt32, pExtendedParameters: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_PARAMETER), pcPropertyCount: POINTER(UInt32), ppProperties: POINTER(POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevFreeObjectProperties(cPropertyCount: UInt32, pProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY)) -> Void: ...
@winfunctype('api-ms-win-devices-query-l1-1-0.dll')
def DevFindProperty(pKey: POINTER(win32more.Windows.Win32.Foundation.DEVPROPKEY), Store: win32more.Windows.Win32.Devices.Properties.DEVPROPSTORE, pszLocaleName: win32more.Windows.Win32.Foundation.PWSTR, cProperties: UInt32, pProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY)) -> POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY): ...
class DEVPROP_FILTER_EXPRESSION(Structure):
    Operator: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR
    Property: win32more.Windows.Win32.Devices.Properties.DEVPROPERTY
DEVPROP_OPERATOR = UInt32
DEVPROP_OPERATOR_MODIFIER_NOT: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 65536
DEVPROP_OPERATOR_MODIFIER_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 131072
DEVPROP_OPERATOR_NONE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 0
DEVPROP_OPERATOR_EXISTS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 1
DEVPROP_OPERATOR_NOT_EXISTS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 65537
DEVPROP_OPERATOR_EQUALS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 2
DEVPROP_OPERATOR_NOT_EQUALS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 65538
DEVPROP_OPERATOR_GREATER_THAN: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 3
DEVPROP_OPERATOR_LESS_THAN: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4
DEVPROP_OPERATOR_GREATER_THAN_EQUALS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 5
DEVPROP_OPERATOR_LESS_THAN_EQUALS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 6
DEVPROP_OPERATOR_EQUALS_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 131074
DEVPROP_OPERATOR_NOT_EQUALS_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 196610
DEVPROP_OPERATOR_BITWISE_AND: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 7
DEVPROP_OPERATOR_BITWISE_OR: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 8
DEVPROP_OPERATOR_BEGINS_WITH: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 9
DEVPROP_OPERATOR_ENDS_WITH: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 10
DEVPROP_OPERATOR_CONTAINS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 11
DEVPROP_OPERATOR_BEGINS_WITH_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 131081
DEVPROP_OPERATOR_ENDS_WITH_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 131082
DEVPROP_OPERATOR_CONTAINS_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 131083
DEVPROP_OPERATOR_LIST_CONTAINS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4096
DEVPROP_OPERATOR_LIST_ELEMENT_BEGINS_WITH: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 8192
DEVPROP_OPERATOR_LIST_ELEMENT_ENDS_WITH: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 12288
DEVPROP_OPERATOR_LIST_ELEMENT_CONTAINS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 16384
DEVPROP_OPERATOR_LIST_CONTAINS_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 135168
DEVPROP_OPERATOR_LIST_ELEMENT_BEGINS_WITH_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 139264
DEVPROP_OPERATOR_LIST_ELEMENT_ENDS_WITH_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 143360
DEVPROP_OPERATOR_LIST_ELEMENT_CONTAINS_IGNORE_CASE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 147456
DEVPROP_OPERATOR_AND_OPEN: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 1048576
DEVPROP_OPERATOR_AND_CLOSE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 2097152
DEVPROP_OPERATOR_OR_OPEN: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 3145728
DEVPROP_OPERATOR_OR_CLOSE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4194304
DEVPROP_OPERATOR_NOT_OPEN: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 5242880
DEVPROP_OPERATOR_NOT_CLOSE: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 6291456
DEVPROP_OPERATOR_ARRAY_CONTAINS: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 268435456
DEVPROP_OPERATOR_MASK_EVAL: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4095
DEVPROP_OPERATOR_MASK_LIST: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 61440
DEVPROP_OPERATOR_MASK_MODIFIER: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 983040
DEVPROP_OPERATOR_MASK_NOT_LOGICAL: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4027580415
DEVPROP_OPERATOR_MASK_LOGICAL: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 267386880
DEVPROP_OPERATOR_MASK_ARRAY: win32more.Windows.Win32.Devices.DeviceQuery.DEVPROP_OPERATOR = 4026531840
class DEV_OBJECT(Structure):
    ObjectType: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE
    pszObjectId: win32more.Windows.Win32.Foundation.PWSTR
    cPropertyCount: UInt32
    pProperties: POINTER(win32more.Windows.Win32.Devices.Properties.DEVPROPERTY)
DEV_OBJECT_TYPE = Int32
DevObjectTypeUnknown: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 0
DevObjectTypeDeviceInterface: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 1
DevObjectTypeDeviceContainer: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 2
DevObjectTypeDevice: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 3
DevObjectTypeDeviceInterfaceClass: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 4
DevObjectTypeAEP: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 5
DevObjectTypeAEPContainer: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 6
DevObjectTypeDeviceInstallerClass: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 7
DevObjectTypeDeviceInterfaceDisplay: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 8
DevObjectTypeDeviceContainerDisplay: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 9
DevObjectTypeAEPService: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 10
DevObjectTypeDevicePanel: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT_TYPE = 11
DEV_QUERY_FLAGS = Int32
DevQueryFlagNone: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_FLAGS = 0
DevQueryFlagUpdateResults: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_FLAGS = 1
DevQueryFlagAllProperties: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_FLAGS = 2
DevQueryFlagLocalize: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_FLAGS = 4
DevQueryFlagAsyncClose: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_FLAGS = 8
class DEV_QUERY_PARAMETER(Structure):
    Key: win32more.Windows.Win32.Foundation.DEVPROPKEY
    Type: win32more.Windows.Win32.Devices.Properties.DEVPROPTYPE
    BufferSize: UInt32
    Buffer: VoidPtr
DEV_QUERY_RESULT_ACTION = Int32
DevQueryResultStateChange: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION = 0
DevQueryResultAdd: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION = 1
DevQueryResultUpdate: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION = 2
DevQueryResultRemove: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION = 3
class DEV_QUERY_RESULT_ACTION_DATA(Structure):
    Action: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION
    Data: _DEV_QUERY_RESULT_UPDATE_PAYLOAD
    class _DEV_QUERY_RESULT_UPDATE_PAYLOAD(Union):
        State: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_STATE
        DeviceObject: win32more.Windows.Win32.Devices.DeviceQuery.DEV_OBJECT
DEV_QUERY_STATE = Int32
DevQueryStateInitialized: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_STATE = 0
DevQueryStateEnumCompleted: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_STATE = 1
DevQueryStateAborted: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_STATE = 2
DevQueryStateClosed: win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_STATE = 3
HDEVQUERY = VoidPtr
@winfunctype_pointer
def PDEV_QUERY_RESULT_CALLBACK(hDevQuery: win32more.Windows.Win32.Devices.DeviceQuery.HDEVQUERY, pContext: VoidPtr, pActionData: POINTER(win32more.Windows.Win32.Devices.DeviceQuery.DEV_QUERY_RESULT_ACTION_DATA)) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Display
import win32more.Windows.Foundation
import win32more.Windows.Graphics
import win32more.Windows.Win32.System.WinRT
class DisplayMonitor(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Display.IDisplayMonitor
    _classid_ = 'Windows.Devices.Display.DisplayMonitor'
    @winrt_mixinmethod
    def get_DeviceId(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ConnectionKind(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Devices.Display.DisplayMonitorConnectionKind: ...
    @winrt_mixinmethod
    def get_PhysicalConnector(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Devices.Display.DisplayMonitorPhysicalConnectorKind: ...
    @winrt_mixinmethod
    def get_DisplayAdapterDeviceId(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayAdapterId(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Graphics.DisplayAdapterId: ...
    @winrt_mixinmethod
    def get_DisplayAdapterTargetId(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> UInt32: ...
    @winrt_mixinmethod
    def get_UsageKind(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Devices.Display.DisplayMonitorUsageKind: ...
    @winrt_mixinmethod
    def get_NativeResolutionInRawPixels(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def get_PhysicalSizeInInches(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Size]: ...
    @winrt_mixinmethod
    def get_RawDpiX(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> Single: ...
    @winrt_mixinmethod
    def get_RawDpiY(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> Single: ...
    @winrt_mixinmethod
    def get_RedPrimary(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_GreenPrimary(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_BluePrimary(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_WhitePoint(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def get_MaxLuminanceInNits(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> Single: ...
    @winrt_mixinmethod
    def get_MinLuminanceInNits(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> Single: ...
    @winrt_mixinmethod
    def get_MaxAverageFullFrameLuminanceInNits(self: win32more.Windows.Devices.Display.IDisplayMonitor) -> Single: ...
    @winrt_mixinmethod
    def GetDescriptor(self: win32more.Windows.Devices.Display.IDisplayMonitor, descriptorKind: win32more.Windows.Devices.Display.DisplayMonitorDescriptorKind) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def get_IsDolbyVisionSupportedInHdrMode(self: win32more.Windows.Devices.Display.IDisplayMonitor2) -> Boolean: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Display.IDisplayMonitorStatics) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Display.IDisplayMonitorStatics, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Display.DisplayMonitor]: ...
    @winrt_classmethod
    def FromInterfaceIdAsync(cls: win32more.Windows.Devices.Display.IDisplayMonitorStatics, deviceInterfaceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Display.DisplayMonitor]: ...
    BluePrimary = property(get_BluePrimary, None)
    ConnectionKind = property(get_ConnectionKind, None)
    DeviceId = property(get_DeviceId, None)
    DisplayAdapterDeviceId = property(get_DisplayAdapterDeviceId, None)
    DisplayAdapterId = property(get_DisplayAdapterId, None)
    DisplayAdapterTargetId = property(get_DisplayAdapterTargetId, None)
    DisplayName = property(get_DisplayName, None)
    GreenPrimary = property(get_GreenPrimary, None)
    IsDolbyVisionSupportedInHdrMode = property(get_IsDolbyVisionSupportedInHdrMode, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    NativeResolutionInRawPixels = property(get_NativeResolutionInRawPixels, None)
    PhysicalConnector = property(get_PhysicalConnector, None)
    PhysicalSizeInInches = property(get_PhysicalSizeInInches, None)
    RawDpiX = property(get_RawDpiX, None)
    RawDpiY = property(get_RawDpiY, None)
    RedPrimary = property(get_RedPrimary, None)
    UsageKind = property(get_UsageKind, None)
    WhitePoint = property(get_WhitePoint, None)
class DisplayMonitorConnectionKind(Enum, Int32):
    Internal = 0
    Wired = 1
    Wireless = 2
    Virtual = 3
class DisplayMonitorDescriptorKind(Enum, Int32):
    Edid = 0
    DisplayId = 1
class DisplayMonitorPhysicalConnectorKind(Enum, Int32):
    Unknown = 0
    HD15 = 1
    AnalogTV = 2
    Dvi = 3
    Hdmi = 4
    Lvds = 5
    Sdi = 6
    DisplayPort = 7
class DisplayMonitorUsageKind(Enum, Int32):
    Standard = 0
    HeadMounted = 1
    SpecialPurpose = 2
class IDisplayMonitor(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Display.IDisplayMonitor'
    _iid_ = Guid('{1f6b15d4-1d01-4c51-87e2-6f954a772b59}')
    @winrt_commethod(6)
    def get_DeviceId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ConnectionKind(self) -> win32more.Windows.Devices.Display.DisplayMonitorConnectionKind: ...
    @winrt_commethod(9)
    def get_PhysicalConnector(self) -> win32more.Windows.Devices.Display.DisplayMonitorPhysicalConnectorKind: ...
    @winrt_commethod(10)
    def get_DisplayAdapterDeviceId(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_DisplayAdapterId(self) -> win32more.Windows.Graphics.DisplayAdapterId: ...
    @winrt_commethod(12)
    def get_DisplayAdapterTargetId(self) -> UInt32: ...
    @winrt_commethod(13)
    def get_UsageKind(self) -> win32more.Windows.Devices.Display.DisplayMonitorUsageKind: ...
    @winrt_commethod(14)
    def get_NativeResolutionInRawPixels(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(15)
    def get_PhysicalSizeInInches(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Size]: ...
    @winrt_commethod(16)
    def get_RawDpiX(self) -> Single: ...
    @winrt_commethod(17)
    def get_RawDpiY(self) -> Single: ...
    @winrt_commethod(18)
    def get_RedPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(19)
    def get_GreenPrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(20)
    def get_BluePrimary(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(21)
    def get_WhitePoint(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(22)
    def get_MaxLuminanceInNits(self) -> Single: ...
    @winrt_commethod(23)
    def get_MinLuminanceInNits(self) -> Single: ...
    @winrt_commethod(24)
    def get_MaxAverageFullFrameLuminanceInNits(self) -> Single: ...
    @winrt_commethod(25)
    def GetDescriptor(self, descriptorKind: win32more.Windows.Devices.Display.DisplayMonitorDescriptorKind) -> ReceiveArray[Byte]: ...
    BluePrimary = property(get_BluePrimary, None)
    ConnectionKind = property(get_ConnectionKind, None)
    DeviceId = property(get_DeviceId, None)
    DisplayAdapterDeviceId = property(get_DisplayAdapterDeviceId, None)
    DisplayAdapterId = property(get_DisplayAdapterId, None)
    DisplayAdapterTargetId = property(get_DisplayAdapterTargetId, None)
    DisplayName = property(get_DisplayName, None)
    GreenPrimary = property(get_GreenPrimary, None)
    MaxAverageFullFrameLuminanceInNits = property(get_MaxAverageFullFrameLuminanceInNits, None)
    MaxLuminanceInNits = property(get_MaxLuminanceInNits, None)
    MinLuminanceInNits = property(get_MinLuminanceInNits, None)
    NativeResolutionInRawPixels = property(get_NativeResolutionInRawPixels, None)
    PhysicalConnector = property(get_PhysicalConnector, None)
    PhysicalSizeInInches = property(get_PhysicalSizeInInches, None)
    RawDpiX = property(get_RawDpiX, None)
    RawDpiY = property(get_RawDpiY, None)
    RedPrimary = property(get_RedPrimary, None)
    UsageKind = property(get_UsageKind, None)
    WhitePoint = property(get_WhitePoint, None)
class IDisplayMonitor2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Display.IDisplayMonitor2'
    _iid_ = Guid('{023018e6-cb23-5830-96df-a7bf6e602577}')
    @winrt_commethod(6)
    def get_IsDolbyVisionSupportedInHdrMode(self) -> Boolean: ...
    IsDolbyVisionSupportedInHdrMode = property(get_IsDolbyVisionSupportedInHdrMode, None)
class IDisplayMonitorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Display.IDisplayMonitorStatics'
    _iid_ = Guid('{6eae698f-a228-4c05-821d-b695d667de8e}')
    @winrt_commethod(6)
    def GetDeviceSelector(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Display.DisplayMonitor]: ...
    @winrt_commethod(8)
    def FromInterfaceIdAsync(self, deviceInterfaceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Display.DisplayMonitor]: ...


make_ready(__name__)
